# Terra Nanotech Discordbot Cogs

A collection of cogs for
[AA-Discordbot](https://github.com/pvyParts/allianceauth-discordbot)


```shell
pip install tnnt-discordbot-cogs
```

In `local.py` right after `INSTALLED_APPS`:

```python
# Terra Nanotech Discordbot Cogs
INSTALLED_APPS += ["tnnt_discordbot_cogs"]
```
